@@ -61,7 +61,7 @@ int main(int argc, char *argv[])
 #endif
 
 	if (gnome_vfs_init() == FALSE) {
-		g_warning("Gaaaaaaaah! Gnome-VFS init failed mate !\n");
+		g_warning(_("GNOME VFS initialization failed!\n"));
 		exit(1);
 	}
 
@@ -493,19 +493,21 @@ void quit_app(GtkWidget * a, gpointer user_data)
 void about_app(GtkWidget * a, gpointer user_data)
 {
 	static GtkWindow *about = NULL;
-	gchar* authors[] = { "Ole Aamot",
-			     "Marek Černocký",
-			     "Miroslav Nikolić",
-			     "Wolfgang Stöggl",
-			     "Piotr Drąg",
-			     "Muhammet Kara",
-			     "Balázs Úr",
+	gchar* authors[] = { "Ole Aamot (Maintainer)",
+			     "Marek Černocký (Czech translation)",
+			     "Rafael Ferreira (Brazilian Portuguese translation)",
+			     "Miroslav Nikolić (Serbian translation)",
+			     "Wolfgang Stöggl (German translation)",
+			     "Piotr Drąg (Polish translation)",
+			     "Muhammet Kara (Turkish translation)",
+			     "Balázs Úr (Hungarian translation)",
+			     "Andika Triwidada (Indonesian translation)",
 			     NULL };
 	gchar* artists[] = { "Wiki Graphic Designer",
 			     "Aly Raj",
 			     NULL };
-	gchar* comments = { "Locate Internet Radio Stations" };
-	gchar* copyright = { "Copyright (C) 2014, 2015  Ole Aamot Software" };
+	gchar* comments = { _("Locate Internet Radio Stations") };
+	gchar* copyright = { _("Copyright (C) 2014, 2015  Ole Aamot Software") };
 	gchar* documenters[] = { NULL };
 
 	static GdkPixbuf* logo;
@@ -518,7 +520,7 @@ void about_app(GtkWidget * a, gpointer user_data)
 		GError* error = NULL;
 		logo = gdk_pixbuf_new_from_file (GIRL_DATADIR "/girl.png", &error);
 		if (error) {
-			g_warning ("Unable to load GIRL logo: %s\n", error->message);
+			g_warning (_("Unable to load GIRL logo: %s\n"), error->message);
 			g_error_free (error);
 		}
 	}
